'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _colors = require('colors');

var _colors2 = _interopRequireDefault(_colors);

var _path = require('path');

var _fs = require('../utils/fs');

var _utils = require('../utils');

var _clearConsole = require('react-dev-utils/clearConsole');

var _clearConsole2 = _interopRequireDefault(_clearConsole);

var _webpackCommon = require('../webpack/webpack.common.js');

var _webpackCommon2 = _interopRequireDefault(_webpackCommon);

var _webpackProd = require('../webpack/webpack.prod.js');

var _webpackProd2 = _interopRequireDefault(_webpackProd);

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function () {
  var config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '.luciorc.js';

  (0, _clearConsole2.default)();
  // read config
  var configPath = (0, _path.join)(process.cwd(), config);

  var webpackConfig = {};
  if ((0, _fs.exists)(configPath)) {
    webpackConfig = require(configPath);
  }

  var _webpackConfig = webpackConfig,
      _webpackConfig$output = _webpackConfig.output,
      output = _webpackConfig$output === undefined ? './dist' : _webpackConfig$output;

  var webpackCommon = (0, _webpackCommon2.default)(webpackConfig, 'production');
  var webpackProd = _extends({}, webpackCommon, (0, _webpackProd2.default)(webpackConfig));

  console.log('Creating an optimized production build...'.bold.green);
  console.log();
  console.log('  Clean folder ' + output);
  console.log();
  (0, _fs.rmdir)((0, _path.resolve)(output));
  console.log('  Building...');
  (0, _webpack2.default)(webpackProd).run(function (error, stats) {

    (0, _clearConsole2.default)();

    if (error) {
      (0, _utils.printError)(error);
      process.exit(1);
    }

    (0, _utils.runArray)(stats.stats || stats, function (item) {
      if (item.compilation.errors.length) {
        (0, _utils.printError)(item.compilation.errors);
        process.exit(1);
      }
    });

    if (stats.stats) {
      console.log(chalk.green('Compiled successfully.'));
    } else {
      console.log(('Compiled success in ' + (stats.toJson().time / 1000).toFixed(1) + 's').bold.green);
      console.log();
      console.log('Analyze result is generated at ' + 'dist/stats.html'.bold.green);
      console.log();
      console.log('File sizes after gzip:');
      console.log();
      (0, _utils.printFileSize)(output);
    }
  });
};

module.exports = exports['default'];