'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _colors = require('colors');

var _colors2 = _interopRequireDefault(_colors);

var _path = require('path');

var _fs = require('../utils/fs');

var _clearConsole = require('react-dev-utils/clearConsole');

var _clearConsole2 = _interopRequireDefault(_clearConsole);

var _webpackDll = require('../webpack/webpack.dll.js');

var _webpackDll2 = _interopRequireDefault(_webpackDll);

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function () {
  var config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '.luciorc.js';

  (0, _clearConsole2.default)();
  // 读取配置文件
  var configPath = (0, _path.join)(process.cwd(), config);
  var webpackConfig = {};
  if ((0, _fs.exists)(configPath)) {
    webpackConfig = require(configPath);
  }

  var _webpackConfig = webpackConfig,
      _webpackConfig$common = _webpackConfig.commons,
      commons = _webpackConfig$common === undefined ? [] : _webpackConfig$common;


  if (commons.length === 0) {
    console.log('Option commons can not be empty'.bold.red);
    process.exit(1);
  }

  var webpackDll = (0, _webpackDll2.default)(commons);

  console.log('Creating an optimized commons build...'.bold.green);
  console.log();
  console.log('Clean folder ./node_modules/lucio.dll');
  console.log();

  (0, _fs.rmdir)((0, _path.resolve)('./node_modules/lucio.dll'));

  (0, _webpack2.default)(webpackDll).run(function (error, stats) {
    (0, _clearConsole2.default)();

    if (error) {
      console.log('Failed to compile: '.bold.red, [error]);
      process.exit(1);
    }

    if (stats.compilation.errors.length) {
      console.log('Failed to compile: '.bold.red, stats.compilation.errors);
      process.exit(1);
    }

    console.log(('Compiled success in ' + (stats.toJson().time / 1000).toFixed(1) + 's').bold.green);
    console.log();
    console.log('To start the development server, use ' + 'lucio start'.magenta);
  });
};

module.exports = exports['default'];