'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _colors = require('colors');

var _colors2 = _interopRequireDefault(_colors);

var _path = require('path');

var _fs = require('../utils/fs');

var _webpackCommon = require('../webpack/webpack.common.js');

var _webpackCommon2 = _interopRequireDefault(_webpackCommon);

var _webpackDev = require('../webpack/webpack.dev.js');

var _webpackDev2 = _interopRequireDefault(_webpackDev);

var _webpackDevServer = require('webpack-dev-server');

var _webpackDevServer2 = _interopRequireDefault(_webpackDevServer);

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

var _chokidar = require('chokidar');

var _chokidar2 = _interopRequireDefault(_chokidar);

var _clearConsole = require('react-dev-utils/clearConsole');

var _clearConsole2 = _interopRequireDefault(_clearConsole);

var _formatWebpackMessages = require('react-dev-utils/formatWebpackMessages');

var _formatWebpackMessages2 = _interopRequireDefault(_formatWebpackMessages);

var _openBrowser = require('react-dev-utils/openBrowser');

var _openBrowser2 = _interopRequireDefault(_openBrowser);

var _connectHistoryApiFallback = require('connect-history-api-fallback');

var _connectHistoryApiFallback2 = _interopRequireDefault(_connectHistoryApiFallback);

var _WebpackDevServerUtils = require('react-dev-utils/WebpackDevServerUtils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var start = function start() {
  var config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '.luciorc.js';
  var port = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '9000';
  var https = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  var dll = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;

  // 初始化标识
  var init = true;
  // 读取配置文件
  var configPath = (0, _path.join)(process.cwd(), config);

  var webpackConfig = {};
  if ((0, _fs.exists)(configPath)) {
    webpackConfig = require(configPath);
  }

  (0, _WebpackDevServerUtils.choosePort)('0.0.0.0', parseInt(port)).then(function (port) {
    if (port === null) {
      return;
    }

    var webpackCommon = (0, _webpackCommon2.default)(webpackConfig, 'development');
    var webpackDev = _extends({}, webpackCommon, (0, _webpackDev2.default)(webpackConfig, dll));

    var compiler = (0, _webpack2.default)(webpackDev);

    compiler.plugin('invalid', function () {
      (0, _clearConsole2.default)();
      console.log('Compiling...'.bold.green);
    });

    compiler.plugin('done', function (stats) {
      (0, _clearConsole2.default)();
      var json = stats.toJson({}, true);
      var messages = (0, _formatWebpackMessages2.default)(json);
      var isOk = !messages.errors.length && !messages.warnings.length;

      if (isOk) {
        if (stats.stats) {
          console.log('Compiled successfully'.bold.green);
        } else {
          console.log(('Compiled successfully in ' + (json.time / 1000).toFixed(1) + 's!').bold.green);
        }
        if (init) {
          console.log();
          console.log("                ,-.");
          console.log("      _,.      /  /");
          console.log("     ; \\____,-==-._  )    " + 'The app is running at:'.green);
          console.log("     //_    `----' {+>     ");
          console.log("     `  `'--/  /-'`(       " + ('  http://127.0.0.1:' + port + '/').magenta);
          console.log("           /  / ");
          console.log("           `='");
          console.log();
          console.log('Note that the development build is not optimized');
          console.log('To create a production build, use ' + 'lucio build'.magenta);
          init = false;
        }
      }

      // If errors exist, only show errors.
      if (messages.errors.length) {
        console.log('Failed to compile'.bold.red);
        console.log();
        messages.errors.forEach(function (message) {
          console.log(message);
          console.log();
        });

        // Show warnings if no errors were found.
      } else if (messages.warnings.length) {
        console.log('Compiled with warnings'.bold.yellow);
        console.log();
        messages.warnings.forEach(function (message) {
          console.log(message);
          console.log();
        });
        // Teach some ESLint tricks.
        console.log('You may use special comments to disable some warnings');
        console.log();
      }
    });
    // config dev server
    var devServer = new _webpackDevServer2.default(compiler, {
      contentBase: (0, _path.resolve)(webpackConfig.output || './dist'),
      hot: true,
      disableHostCheck: true,
      compress: true,
      quiet: true,
      stats: 'minimal',
      host: '0.0.0.0',
      open: true,
      https: https,
      publicPath: '/',
      proxy: webpackConfig.proxy || {}
    });

    // add middleware
    devServer.use((0, _connectHistoryApiFallback2.default)({
      disableDotRule: true,
      htmlAcceptHeaders: ['text/html']
    }));

    devServer.use(devServer.middleware);

    // run dev server
    devServer.listen(port, '0.0.0.0', function (err) {
      if (err) {
        return console.log(err.bold.red);
      }
      (0, _clearConsole2.default)();
      console.log('Starting the development server...'.bold.green);

      (0, _openBrowser2.default)((https ? 'https' : 'http') + '://127.0.0.1:' + port + '/');
    });

    // watch
    var watcher = _chokidar2.default.watch(configPath, {
      ignored: /node_modules/,
      persistent: true
    });

    watcher.on('change', function (path) {
      (0, _clearConsole2.default)();
      console.log(('File ' + config + ' changed, please to restart server').bold.yellow);
      console.log('if you change `' + 'common'.bold.yellow + '`, please run `' + 'lucio dll'.bold.yellow + '`');
      console.log();
      watcher.close();
      devServer.close();
      process.exit(1);
    });
  });
};

exports.default = start;
module.exports = exports['default'];