'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.firstUpperCase = exports.template = undefined;
exports.mapModelToIndex = mapModelToIndex;
exports.mapComponentToRouter = mapComponentToRouter;

var _handlebars = require('handlebars');

var _handlebars2 = _interopRequireDefault(_handlebars);

var _path = require('path');

var _colors = require('colors');

var _colors2 = _interopRequireDefault(_colors);

var _fs = require('./fs');

var _jscodeshift = require('jscodeshift');

var _jscodeshift2 = _interopRequireDefault(_jscodeshift);

var _Collection = require('jscodeshift/dist/Collection');

var _Collection2 = _interopRequireDefault(_Collection);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// 获取模版
var template = exports.template = function template(src, output, data) {
  var handlePath = (0, _path.join)(__dirname, '../../templates/handles', src);
  if (!(0, _fs.exists)(handlePath)) {
    console.log(('Error: templates file ' + handlePath + ' not exists').bold.red);
    process.exit(1);
  }

  var source = (0, _fs.read)(handlePath, 'utf-8');

  _handlebars2.default.registerHelper('array', function (text, option) {
    return text.join(", ");
  });

  var template = _handlebars2.default.compile(source);

  (0, _fs.write)(output, template(data), 'utf-8');
};

// 首字母大写
var firstUpperCase = exports.firstUpperCase = function firstUpperCase(str) {
  return str.toString()[0].toUpperCase() + str.toString().slice(1);
};

function mapImportToFile(namespace, type) {
  // 读取文件路径
  var filePath = type === 'model' ? (0, _path.join)(process.cwd(), 'src', 'index.js') : (0, _path.join)(process.cwd(), 'src', 'router.js');
  // import路径
  var fileImportPath = type === 'model' ? './routes/' + namespace + '/model' : './routes/' + namespace + '/components';
  var fileImportName = type === 'model' ? namespace : firstUpperCase(namespace);

  if (!existsSync(filePath)) {
    error(filePath + ' \u4E0D\u5B58\u5728');
    process.exit(1);
  }
  try {
    // 文件读取
    var fileBuffer = readFile(filePath);
    // jscodeshift初始化
    var root = (0, _jscodeshift2.default)(fileBuffer);

    var imports = [];
    // 寻找全部的import节点
    root.find(_jscodeshift2.default.ImportDeclaration).forEach(function (p) {
      var node = p.value;
      var specifiers = node.specifiers,
          source = node.source;

      if (source.value.startsWith('./routes')) {
        imports.push(p);
      }
    });

    var JImports = _Collection2.default.fromPaths(imports, root);
    var collection = JImports.at(0);
    // 新的import节点插入
    collection.insertAfter.call(collection, _jscodeshift2.default.importDeclaration([_jscodeshift2.default.importDefaultSpecifier(_jscodeshift2.default.identifier(fileImportName))], _jscodeshift2.default.literal(fileImportPath)));
    return {
      filePath: filePath,
      root: root
    };
  } catch (e) {
    error(e);
  }
}

// 注册model
function mapModelToIndex(namespace) {
  var _mapImportToFile = mapImportToFile(namespace, 'model'),
      root = _mapImportToFile.root,
      filePath = _mapImportToFile.filePath;

  try {
    var models = [];
    root.find(_jscodeshift2.default.CallExpression).forEach(function (p) {
      var node = p.value;
      if (_jscodeshift2.default.MemberExpression.check(node.callee)) {
        var _node$callee = node.callee,
            _object = _node$callee.object,
            _property = _node$callee.property;

        if (_property.name === 'model') {
          models.push(p);
        }
      }
    });

    var JModels = _Collection2.default.fromPaths(models, root);
    var _JModels$get$value$ca = JModels.get().value.callee,
        object = _JModels$get$value$ca.object,
        property = _JModels$get$value$ca.property;

    var collection = JModels.map(function (node) {
      return node.parent;
    }).at(0);

    collection.insertAfter.call(collection, _jscodeshift2.default.expressionStatement(_jscodeshift2.default.callExpression(_jscodeshift2.default.memberExpression(object, _jscodeshift2.default.identifier('model')), [_jscodeshift2.default.identifier(namespace)])));
    // 文件写入
    outputFileSync(filePath, root.toSource(), 'utf-8');
  } catch (e) {
    error(e);
  }
}

// 按需加载 component and model
function mapComponentToRouter(namespace) {
  var _mapImportToFile2 = mapImportToFile(namespace, 'router'),
      root = _mapImportToFile2.root,
      filePath = _mapImportToFile2.filePath;

  try {
    // 寻找router节点
    var findRouterNode = function findRouterNode(root) {
      return root.find(_jscodeshift2.default.JSXElement, {
        openingElement: {
          name: {
            name: 'Route'
          }
        }
      }).nodes()[0];
    };

    var parentRoute = findRouterNode(root);
    // 节点插入
    parentRoute.children.push(_jscodeshift2.default.jsxElement(_jscodeshift2.default.jsxOpeningElement(_jscodeshift2.default.jsxIdentifier('Route'), [_jscodeshift2.default.jsxAttribute(_jscodeshift2.default.jsxIdentifier('path'), _jscodeshift2.default.literal('/' + namespace)), _jscodeshift2.default.jsxAttribute(_jscodeshift2.default.jsxIdentifier('component'), _jscodeshift2.default.jsxExpressionContainer(_jscodeshift2.default.jsxIdentifier(firstUpperCase(namespace))))], true)), _jscodeshift2.default.literal('\n '));
    // 文件写入
    outputFileSync(filePath, root.toSource(), 'utf-8');
  } catch (e) {
    error(e);
  }
}