'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.printFileSize = exports.runArray = exports.printError = undefined;

var _colors = require('colors');

var _colors2 = _interopRequireDefault(_colors);

var _fs = require('../utils/fs');

var _gzipSize = require('gzip-size');

var _filesize = require('filesize');

var _filesize2 = _interopRequireDefault(_filesize);

var _easyTable = require('easy-table');

var _easyTable2 = _interopRequireDefault(_easyTable);

var _path = require('path');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var printError = exports.printError = function printError(errors) {
  console.log('Failed to compile: '.bold.red);
  console.log();
  errors.forEach(function (err) {
    console.log(err.message || err);
    console.log();
  });
  process.exit(1);
};

var runArray = exports.runArray = function runArray(stats, fn) {
  if (stats && Array.isArray(stats)) {
    return stats.map(fn);
  } else {
    return fn(stats);
  }
};

var printFileSize = exports.printFileSize = function printFileSize(output) {
  (0, _fs.readDir)((0, _path.join)(process.cwd(), output), function (err, files) {
    if (err) {
      console.log('Failed to get file gzip size'.bold.red);
    }
    var et = new _easyTable2.default();

    files.filter(function (fn) {
      return (/\.(js|css)$/.test(fn)
      );
    }).map(function (fn) {
      var filePath = (0, _path.join)(process.cwd(), output, fn);
      var content = (0, _fs.read)((0, _path.join)(process.cwd(), output, fn));
      return {
        filename: fn,
        size: (0, _filesize2.default)((0, _fs.size)(filePath)),
        gzip: (0, _filesize2.default)((0, _gzipSize.sync)(content))
      };
    }).forEach(function (_ref) {
      var filename = _ref.filename,
          size = _ref.size,
          gzip = _ref.gzip;

      et.cell('file name'.bold, filename);
      et.cell('size'.bold, size.bold.yellow);
      et.cell('gzip size'.bold, gzip.bold.green);
      et.newRow();
    });
    console.log(et.toString());
  });
};