'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _path = require('path');

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

var _autoprefixer = require('autoprefixer');

var _autoprefixer2 = _interopRequireDefault(_autoprefixer);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

exports.default = function (_ref, env) {
  var _ref$entry = _ref.entry,
      entry = _ref$entry === undefined ? './src/index.js' : _ref$entry,
      _ref$output = _ref.output,
      output = _ref$output === undefined ? './dist' : _ref$output,
      _ref$commons = _ref.commons,
      commons = _ref$commons === undefined ? [] : _ref$commons,
      _ref$postcssPlugins = _ref.postcssPlugins,
      postcssPlugins = _ref$postcssPlugins === undefined ? [] : _ref$postcssPlugins,
      _ref$commonBabelPlugi = _ref.commonBabelPlugins,
      commonBabelPlugins = _ref$commonBabelPlugi === undefined ? [] : _ref$commonBabelPlugi,
      _ref$devBabelPlugins = _ref.devBabelPlugins,
      devBabelPlugins = _ref$devBabelPlugins === undefined ? [] : _ref$devBabelPlugins,
      _ref$prodBabelPlugins = _ref.prodBabelPlugins,
      prodBabelPlugins = _ref$prodBabelPlugins === undefined ? [] : _ref$prodBabelPlugins,
      _ref$resolvePlugins = _ref.resolvePlugins,
      resolvePlugins = _ref$resolvePlugins === undefined ? {} : _ref$resolvePlugins,
      _ref$babelLoaderDir = _ref.babelLoaderDir,
      babelLoaderDir = _ref$babelLoaderDir === undefined ? [] : _ref$babelLoaderDir,
      svgSpriteDir = _ref.svgSpriteDir;

  var babelPlugins = {
    babelrc: false,
    plugins: [require.resolve('babel-plugin-add-module-exports'), require.resolve('babel-plugin-react-require'), require.resolve('babel-plugin-syntax-dynamic-import')].concat(commonBabelPlugins).concat(env === 'development' ? devBabelPlugins : prodBabelPlugins),
    presets: [require.resolve('babel-preset-es2015'), require.resolve('babel-preset-react'), require.resolve('babel-preset-stage-0')]
  };

  var postcss = [(0, _autoprefixer2.default)({
    browsers: ['>1%', 'last 4 versions', 'Firefox ESR', 'not ie < 9']
  })].concat(_toConsumableArray(postcssPlugins));

  var createEntry = function createEntry() {
    if (env === 'development') {
      return {
        index: [require.resolve('react-dev-utils/webpackHotDevClient'), (0, _path.resolve)(entry)]
      };
    } else {
      if (commons.length === 0) {
        return {
          index: (0, _path.resolve)(entry)
        };
      } else {
        return {
          index: (0, _path.resolve)(entry),
          commons: commons
        };
      }
    }
  };

  var webpackConfig = {
    entry: createEntry(),
    output: {
      filename: '[name].[' + (env === 'development' ? 'hash' : 'chunkhash') + '].js',
      publicPath: '/',
      path: (0, _path.resolve)(output)
    },
    module: {
      rules: [{
        test: /\.(js|jsx)$/,
        include: [(0, _path.resolve)(entry.split('/')[1])].concat(_toConsumableArray(babelLoaderDir)),
        use: {
          loader: 'babel-loader',
          options: babelPlugins
        }
      }, {
        test: /\.css$/,
        use: ['style-loader', 'css-loader']
      }, {
        test: /\.less$/,
        use: ['style-loader', 'css-loader', {
          loader: 'postcss-loader',
          options: {
            plugins: postcss
          }
        }, 'less-loader']
      }, {
        test: /\.(png|jpg|gif)$/,
        use: 'url-loader'
      }, {
        test: /\.woff(\?v=\d+\.\d+\.\d+)?$/,
        use: {
          loader: 'url-loader',
          options: {
            limit: 8192,
            mimetype: 'application/font-woff'
          }
        }
      }, {
        test: /\.woff2(\?v=\d+\.\d+\.\d+)?$/,
        use: {
          loader: 'url-loader',
          options: {
            limit: 8192,
            mimetype: 'application/font-woff2'
          }
        }
      }, {
        test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/,
        use: {
          loader: 'url-loader',
          options: {
            limit: 8192,
            mimetype: 'application/octet-stream'
          }
        }
      }, {
        test: /\.eot(\?v=\d+\.\d+\.\d+)?$/,
        use: 'file-loader'
      }]
    },
    resolve: _extends({
      extensions: ['.js', '.jsx', '.web.js']
    }, resolvePlugins)
  };

  // add svg sprite
  if (svgSpriteDir) {
    webpackConfig.module.rules.unshift({
      test: /\.(svg)$/i,
      use: 'svg-sprite-loader',
      include: svgSpriteDir
    });
  };

  return webpackConfig;
};

module.exports = exports['default'];