import colors from 'colors';
import { join, resolve } from 'path';
import { exists, rmdir } from '../utils/fs';
import { runArray, printError, printFileSize } from '../utils'
import clearConsole from 'react-dev-utils/clearConsole';
import getWebpackCommon from '../webpack/webpack.common.js';
import getWebpackProd from '../webpack/webpack.prod.js';
import webpack from 'webpack';



export default (config = '.luciorc.js') => {
  clearConsole();
  // read config
  const configPath = join(process.cwd(), config);

  let webpackConfig = {};
  if (exists(configPath)) {
    webpackConfig = require(configPath);
  }

  const { output = './dist' } = webpackConfig;
  const webpackCommon = getWebpackCommon(webpackConfig, 'production');
  const webpackProd = {...webpackCommon, ...getWebpackProd(webpackConfig)};

  console.log(`Creating an optimized production build...`.bold.green);
  console.log();
  console.log(`  Clean folder ${output}`);
  console.log();
  rmdir(resolve(output));
  console.log(`  Building...`);
  webpack(webpackProd).run((error, stats) => {
    
    clearConsole();

    if (error) {
      printError(error)
      process.exit(1);
    }

    runArray(stats.stats || stats, (item) => {
      if (item.compilation.errors.length) {
        printError(item.compilation.errors);
        process.exit(1);
      }
    });

    if (stats.stats) {
      console.log(chalk.green('Compiled successfully.'));
    } else {
      console.log(`Compiled success in ${(stats.toJson().time / 1000).toFixed(1)}s`.bold.green);
      console.log();
      console.log(`Analyze result is generated at ${'dist/stats.html'.bold.green}`);
      console.log();
      console.log('File sizes after gzip:');
      console.log();
      printFileSize(output);
    }
  });
}