import colors from 'colors';
import { join, resolve } from 'path';
import { exists, rmdir } from '../utils/fs';
import clearConsole from 'react-dev-utils/clearConsole';
import getWebpackDll from '../webpack/webpack.dll.js';
import webpack from 'webpack';

export default (config = '.luciorc.js') => {
  clearConsole();
  // 读取配置文件
  const configPath = join(process.cwd(), config);
  let webpackConfig = {};
  if (exists(configPath)) {
    webpackConfig = require(configPath);
  }

  const { commons = [] } = webpackConfig;
  
  if (commons.length === 0) {
    console.log('Option commons can not be empty'.bold.red);
    process.exit(1);
  }

  const webpackDll = getWebpackDll(commons);

  console.log(`Creating an optimized commons build...`.bold.green);
  console.log();
  console.log(`Clean folder ./node_modules/lucio.dll`);
  console.log();

  rmdir(resolve('./node_modules/lucio.dll'));

  webpack(webpackDll).run((error, stats) => {
    clearConsole();

    if (error) {
      console.log('Failed to compile: '.bold.red, [error]);
      process.exit(1);
    }

    if (stats.compilation.errors.length) {
      console.log('Failed to compile: '.bold.red, stats.compilation.errors);
      process.exit(1);
    }

    console.log(`Compiled success in ${(stats.toJson().time / 1000).toFixed(1)}s`.bold.green);
    console.log();
    console.log(`To start the development server, use ${'lucio start'.magenta}`);
  });
}