import vfs from 'vinyl-fs';
import colors from 'colors';
import { join, resolve } from 'path';
import { exists, rename, mkdir } from '../utils/fs';
import { template } from '../utils/handle'
import pk from '../../package.json';

export default (pkgname, install, mobile) => {
  const dest = join(process.cwd(), pkgname);
  if(exists(dest)){
    console.log(`ERROR: ${dest} already exists`.bold.red);
    process.exit(1);
  }
    
  mkdir(dest);
  process.chdir(dest);
  const templates = join(__dirname, '../../templates/init');
  
  console.log("                ,-.");
  console.log("      _,.      /  /");
  console.log("     ; \\____,-==-._  )     " + "lucio^" + pk.version.magenta);
  console.log("     //_    `----' {+>     " + "jzs0914@126.com".yellow);
  console.log("     `  `'--/  /-'`(       " + "github.com\/jindada".yellow.underline);
  console.log("           /  /");
  console.log("           `='");
  console.log();

  console.log(`1. copy template file ...`.yellow);

  vfs.src(['**/*', '!node_modules/**/*'], {cwd: templates, cwdbase: true, dot: true})
  .pipe(vfs.dest(dest))
  .on('end', () => {
    rename(join(dest, 'editorconfig'), join(dest, '.editorconfig'));
    rename(join(dest, 'eslintrc'), join(dest, '.eslintrc'));
    rename(join(dest, 'eslintignore'), join(dest, '.eslintignore'));

    console.log(`2. rename template file ...`.yellow);
    // template 
    template('/init/package.json', join(process.cwd(), 'package.json'), { mobile });
    template('/init/index.js', join(process.cwd(), 'src/container/index.js'), { mobile });
    template('/init/index.ejs', join(process.cwd(), 'src/index.ejs'), { mobile });
    template('/init/luciorc.js', join(process.cwd(), '.luciorc.js'), { mobile });

    if (install) {
      console.log(`4. install node modules ...`.yellow);
      var runner = require('child_process').spawn(process.platform === 'win32' ? 'npm.cmd' : 'npm', ['install'], {stdio: "inherit"});
      runner.on('close', function (code) {
        console.log();
        console.log('init success'.bold.green);
        console.log();
        console.log(`you can exec ${'lucio dll'.magenta} && ${'lucio start'.magenta} start service`);
      });
    } else {
      console.log();
      console.log('init success'.bold.green);
      console.log();
      console.log(`you can exec ${'lucio dll && lucio start'.magenta} start service`);
    }
  })
  .resume();
}
