#!/usr/bin/env node
'use strict';
import program from 'commander';
import { join } from 'path';
import colors from 'colors';
import { existsSync } from 'fs';
import pk from '../package.json';

program
  .version(pk.version, '-v, --version')

// init
program
  .command('init <pkgname>')
  .description('initialize project')
  .option('-i, --install', 'automatic install required modules')
  .option('-m, --mobile', 'create mobile app')
  .action((pkgname, { install, mobile }) => {
    require('./command/init.js')(pkgname, install, mobile);
  });


program
  .command('start')
  .description('starting the development server')
  .option('-c, --config <config>', '...')
  .option('-p, --port <port>', '...')
  .option('-s, --https', '...')
  .option('-d, --dll', '...')
  .action(({config, port, https, dll}) => {
    require('./command/start.js')(config, port, https, dll);
  });

program
  .command('dll')
  .description('creating an optimized commons build')
  .option('-c, --config <config>', '...')
  .action(({ config }) => {
    require('./command/dll.js')(config);
  });

program
  .command('build')
  .description('creating an optimized production build')
  .option('-c, --config <config>', '...')
  .action(({ config }) => {
    require('./command/build.js')(config);
  });

program
  .command('eslint')
  .description('creating an optimized production build')
  .option('-c, --config <config>', '...')
  .option('-p, --path <path>', '...')
  .action(({ config, path }) => {
    require('./command/eslint.js')(config, path);
  });

// TODO add init routes modules
  
program.parse(process.argv);