import { template, readFile, error, success, info, firstUpperCase, mapModelToIndex, mapComponentToRouter } from './utils';
import assert from 'assert';
import { extname, join } from 'path';
import { existsSync } from 'fs';
import { mkdirpSync } from 'fs-extra';
import spoof from './spoof';

const succtips = (name, dest) => (
`
创建模块 ${name} 成功， 路径 ${dest}
如果你有任何疑问, 请联系jzs0914@126.com!
`
)

export default ()  => {
    // 验证模版配置文件
    const rootPath = process.cwd();
    const configPath = join(rootPath, '.lucio.curd.js');
    if(!existsSync(configPath)){
        error(`${configPath} 配置文件不存在`)
    }
    try{
        const config = spoof(configPath);
        config.uppercase = firstUpperCase(config.namespace);
        // 读取模版配置文件
        const dest = join(process.cwd(), './src/routes', config.namespace);
        if(existsSync(dest)){
            error(`${dest} 文件夹已经存在`);
        }
        success(`通过 Lucio 创建一个新的 dva 模版 在 ${dest}.`);
        // 验证namespace
        mkdirpSync(dest); 
        info('目录创建', `src/routes/${config.namespace}`);
    	process.chdir(dest);
        // write model.js
        template("model.js", "curd", config);
        info('文件创建', `src/routes/${config.namespace}/model.js`);
        // write http.js
        template("service.js", "curd", config);
        info('文件创建', `src/routes/${config.namespace}/service.js`);
        // mkdir components
        const cdest = mkdirpSync(join(process.cwd(), 'components'));
        process.chdir(cdest);
        // write index.js
        template("index.js", "curd", config);
        info('文件创建', `src/routes/${config.namespace}/component/index.js`);
        // write table.js

        template("columns.js", "curd", config);
        info('文件创建', `src/routes/${config.namespace}/component/columns.js`);
        // write index.less
        template("style.less", "curd", config);
        info('文件创建', `src/routes/${config.namespace}/component/style.less`);
        
        process.chdir(rootPath);
        // 修改index.js
        mapModelToIndex(config.namespace);
        info('依赖注入', `src/index.js -> model`);
        mapComponentToRouter(config.namespace);
        info('依赖注入', `src/router.js -> component`);
        // print success
        success(succtips(config.namespace, dest));
    }catch(e){
        error(e);
    }
};