import colors from 'colors';
import { readDir, read, size } from '../utils/fs';
import { sync as gzipSize } from 'gzip-size';
import filesize from 'filesize';
import easyTable from 'easy-table';
import { join } from 'path';

export const printError = (errors) => {
  console.log('Failed to compile: '.bold.red);
  console.log();
  errors.forEach(err => {
    console.log(err.message || err);
    console.log();
  })
  process.exit(1);
}

export const runArray = (stats, fn) => {
  if (stats && Array.isArray(stats)) {
    return stats.map(fn);
  } else {
    return fn(stats);
  }
}

export const printFileSize = (output) => {
  readDir(join(process.cwd(), output), (err, files) => {
    if (err) {
      console.log('Failed to get file gzip size'.bold.red);
    }
    const et = new easyTable();

    files.filter(fn => /\.(js|css)$/.test(fn)).map(fn => {
      const filePath = join(process.cwd(), output, fn);
      const content = read(join(process.cwd(), output, fn));
      return {
        filename: fn,
        size: filesize(size(filePath)),
        gzip: filesize(gzipSize(content))
      };        
    }).forEach(({ filename, size, gzip }) => {
      et.cell('file name'.bold, filename);
      et.cell('size'.bold, size.bold.yellow);
      et.cell('gzip size'.bold, gzip.bold.green);
      et.newRow();
    });
    console.log(et.toString());
  });
}