import webpack from 'webpack';
import { resolve } from 'path'
import HtmlWebpackPlugin from 'html-webpack-plugin';
import CopyWebpackPlugin from 'copy-webpack-plugin';

export default ({entry = './src/index.js', output = './dist', template = resolve(entry.split('/')[1], 'index.ejs')}, dll) => {
  
  let webpackConfig = {
    devtool: 'inline-source-map',
    plugins: [
      new webpack.DefinePlugin({
        'process.env.NODE_ENV': '"development"'
      }),
      new webpack.HotModuleReplacementPlugin(),
      new HtmlWebpackPlugin({
        template,
        minify: {
          removeComments: true,
          collapseWhitespace: true
        },
        inject: true,
        nodeEnv: 'development'
      })
    ],
  };

  if (dll) {
    // DllReferencePlugin
    webpackConfig.plugins.push(new webpack.DllReferencePlugin({
      context: process.cwd(),
      manifest: resolve('./node_modules/lucio.dll/', 'manifest.json'),
    }));
    // CopyWebpackPlugin
    webpackConfig.plugins.push(new CopyWebpackPlugin([
      {
        from: resolve('./node_modules/lucio.dll/', 'lucio.dll.js'),
        to: resolve(output, 'lucio.dll.js'),
      },
    ]))
  };

  return webpackConfig;
};