import webpack from 'webpack';
import { resolve } from 'path'
import HtmlWebpackPlugin from 'html-webpack-plugin';
import Visualizer from 'webpack-visualizer-plugin';
import common from './webpack.common.js';


export default ({entry = './src/index.js', commons = [], template = resolve(entry.split('/')[1], 'index.ejs')}) => {

  let webpackProdConfig = {
    devtool: 'source-map',
    plugins: [
      new webpack.DefinePlugin({
        'process.env.NODE_ENV': '"production"'
      }),
      
      new webpack.optimize.UglifyJsPlugin({
        sourceMap: true,
        comments: false, // 去掉注释
        compress: {
            unused: true,
            dead_code: true,
            warnings: false
        }
      }),
      new HtmlWebpackPlugin({
        template,
        minify: {
          removeComments: true,
          collapseWhitespace: true
        },
        inject: true,
        nodeEnv: 'production'
      }),
      new Visualizer()
    ]
  }

  if (commons.length > 0) {
    webpackProdConfig.plugins.push(new webpack.optimize.CommonsChunkPlugin({name: ['commons', 'runtime']}));
  }

  return webpackProdConfig;
};