import { routerRedux } from 'dva/router';
import { login, refreshToken, auth, mark } from './service';
import { Application } from 'antui-admin/lib/utils/storage';
import { pluginConfig } from '../../config';

export default {
  namespace: 'login',
  state: {
    mark: [],
    loading: false
  },
  subscriptions: {
    setup({ dispatch, history }) {
      history.listen(({pathname, query}) => {
        if (pathname === '/login') {
          if (query.userId && query.password) {
            dispatch({ type: 'loading', loading: true });
            dispatch({ type: 'login', values: query });
          } else {
            dispatch({ type: 'loading', loading: false });
          }
        }
      });
    }
  },
  effects: {
    * login({ values }, { put, call }) {
      const { status, data, message } = yield call(login, {...values, ...pluginConfig});
      if (status) {
        // 跳转
        Application.setAttribute("Authorization", data.token);
        Application.setAttribute("userId", data.userId);
        yield put({ type: 'auth' });
      } else {
        throw Error(message);
      }
    },
    * refreshToken(action, {select, put, call}) {
      const { status, data, message } = yield call(refreshToken, {userId: Application.getAttribute("userId")});
      if (status) {
        Application.setAttribute("Authorization", data.token);
      } else {
        throw Error(message);
      }
    },
    * auth(action, {select, put, call}) {
      const userId = Application.getAttribute('userId');
      const { status, data, message } = yield call(auth, { userId, ...pluginConfig });
      if (status) {
        Application.setAttribute("menu", (data[0] || {}).children);
        yield put(routerRedux.push('/param'));
        yield put({ type: 'loading' });
      } else {
        throw Error(message);
      }
    }
  },
  reducers: {
    loading(state, { loading }) {
      return {...state, loading};
    }
  }
};